@@ -189,7 +189,7 @@ struct activity irq_act = {
 	.g_nr		= 0,
 	.nr_ini		= -1,
 	.nr2		= -1,
-	.nr_max		= NR_IRQS + 1,
+	.nr_max		= NR_CPUS + 1,
 	.nr		= {-1, -1, -1},
 	.nr_allocated	= 0,
 	.fsize		= STATS_IRQ_SIZE,
@@ -1834,10 +1834,10 @@ struct activity softnet_act = {
 #endif
 #ifdef SOURCE_SAR
 	.f_print	= print_softnet_stats,
-	.f_print_avg	= print_softnet_stats,
+	.f_print_avg	= print_avg_softnet_stats,
 #endif
 #if defined(SOURCE_SAR) || defined(SOURCE_SADF)
-	.hdr_line	= "CPU;total/s;dropd/s;squeezd/s;rx_rps/s;flw_lim/s",
+	.hdr_line	= "CPU;total/s;dropd/s;squeezd/s;rx_rps/s;flw_lim/s;blg_len",
 #endif
 	.gtypes_nr	= {STATS_SOFTNET_ULL, STATS_SOFTNET_UL, STATS_SOFTNET_U},
 	.ftypes_nr	= {0, 0, 0},
@@ -1854,7 +1854,7 @@ struct activity softnet_act = {
 #endif
 	.name		= "A_NET_SOFT",
 	.item_list_sz	= 0,
-	.g_nr		= 2,
+	.g_nr		= 3,
 	.nr_ini		= -1,
 	.nr2		= 1,
 	.nr_max		= NR_CPUS + 1,
