@@ -434,6 +434,29 @@ int check_dir(char *dirname)
 	return 0;
 }
 
+/*
+ * **************************************************************************
+ * Check if the multiplication of the 3 values may be greater than UINT_MAX.
+ *
+ * IN:
+ * @val1	First value.
+ * @val2	Second value.
+ * @val3	Third value.
+ ***************************************************************************
+ */
+void check_overflow(unsigned int val1, unsigned int val2,
+		    unsigned int val3)
+{
+	if ((unsigned long long) val1 * (unsigned long long) val2 *
+	    (unsigned long long) val3 > UINT_MAX) {
+#ifdef DEBUG
+		fprintf(stderr, "%s: Overflow detected (%llu). Aborting...\n",
+			__FUNCTION__, (unsigned long long) val1 * (unsigned long long) val2 *
+			(unsigned long long) val3);
+#endif
+	exit(4);
+		}
+}
 
 #ifndef SOURCE_SADC
 /*
@@ -948,6 +971,7 @@ char *get_persistent_name_from_pretty(char *pretty)
 		return (NULL);
 
 	while (persist_names[++i]) {
+
 		/* Get absolute path for current persistent name */
 		link = get_persistent_name_path(persist_names[i]);
 		if (!link)
@@ -1510,6 +1534,7 @@ void cprintf_s(int type, char *format, char *string)
 	else if (type == IS_ZERO) {
 		printf("%s", sc_zero_int_stat);
 	}
+	/* IS_RESTART and IS_DEBUG are the same value */
 	else if (type == IS_RESTART) {
 		printf("%s", sc_sa_restart);
 	}
@@ -1659,4 +1684,5 @@ int parse_values(char *strargv, unsigned char bitmap[], int max_val, const char
 
 	return 0;
 }
+
 #endif /* SOURCE_SADC undefined */
