@@ -212,6 +212,7 @@ extern char persistent_name_type[MAX_FILE_LEN];
 #define IS_INT		0
 #define IS_STR		1
 #define IS_RESTART	2
+#define IS_DEBUG	IS_RESTART
 #define IS_COMMENT	3
 #define IS_ZERO		4
 
@@ -255,6 +256,8 @@ int get_wwnid_from_pretty
 	(char *, unsigned long long *, unsigned int *);
 int check_dir
 	(char *);
+void check_overflow
+	(unsigned int, unsigned int, unsigned int);
 
 #ifndef SOURCE_SADC
 int count_bits
