@@ -1,6 +1,6 @@
 /*
  * pidstat: Display per-process statistics.
- * (C) 2007-2020 by Sebastien Godard (sysstat <at> orange.fr)
+ * (C) 2007-2022 by Sebastien Godard (sysstat <at> orange.fr)
  */
 #ifndef _PIDSTAT_H
 #define _PIDSTAT_H
@@ -70,6 +70,7 @@
 #define P_F_PROCSTR	0x0400
 #define P_D_UNIT	0x0800
 #define P_D_SEC_EPOCH	0x1000
+#define P_F_EXEC_PGM	0x2000
 
 #define DISPLAY_PID(m)		(((m) & P_D_PID) == P_D_PID)
 #define DISPLAY_ALL_PID(m)	(((m) & P_D_ALL_PID) == P_D_ALL_PID)
@@ -84,6 +85,7 @@
 #define PROCESS_STRING(m)	(((m) & P_F_PROCSTR) == P_F_PROCSTR)
 #define DISPLAY_UNIT(m)		(((m) & P_D_UNIT) == P_D_UNIT)
 #define PRINT_SEC_EPOCH(m)	(((m) & P_D_SEC_EPOCH) == P_D_SEC_EPOCH)
+#define EXEC_PGM(m)		(((m) & P_F_EXEC_PGM) == P_F_EXEC_PGM)
 
 /* Per-process flags */
 #define F_NO_PID_IO	0x01
